summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorDan Gohman <gohman@apple.com>2012-05-14 18:58:10 +0000
committerDan Gohman <gohman@apple.com>2012-05-14 18:58:10 +0000
commita6063c6e29746d9425bdf46d680e28a48dcf58f9 (patch)
treec79e1e95b6433d484b399f9857ea69395c274511 /include
parent19e7421243df6456dcebc47a650bd37e09b1f92f (diff)
downloadllvm-a6063c6e29746d9425bdf46d680e28a48dcf58f9.tar.gz
Rename @llvm.debugger to @llvm.debugtrap.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@156774 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/CodeGen/ISDOpcodes.h4
-rw-r--r--include/llvm/Intrinsics.td4
-rw-r--r--include/llvm/Target/TargetSelectionDAG.td2
3 files changed, 5 insertions, 5 deletions
diff --git a/include/llvm/Intrinsics.td b/include/llvm/Intrinsics.td
index 6b09cbd7854b..58b178f25afc 100644
--- a/include/llvm/Intrinsics.td
+++ b/include/llvm/Intrinsics.td
@@ -399,8 +399,8 @@ def int_flt_rounds : Intrinsic<[llvm_i32_ty]>,
GCCBuiltin<"__builtin_flt_rounds">;
def int_trap : Intrinsic<[]>,
GCCBuiltin<"__builtin_trap">;
-def int_debugger : Intrinsic<[]>,
- GCCBuiltin<"__builtin_debugger">;
+def int_debugtrap : Intrinsic<[]>,
+ GCCBuiltin<"__builtin_debugtrap">;
// Intrisics to support half precision floating point format
let Properties = [IntrNoMem] in {
diff --git a/include/llvm/Target/TargetSelectionDAG.td b/include/llvm/Target/TargetSelectionDAG.td
index 361b42a12b5f..5f069801a6d4 100644
--- a/include/llvm/Target/TargetSelectionDAG.td
+++ b/include/llvm/Target/TargetSelectionDAG.td
@@ -404,7 +404,7 @@ def brind : SDNode<"ISD::BRIND" , SDTBrind, [SDNPHasChain]>;
def br : SDNode<"ISD::BR" , SDTBr, [SDNPHasChain]>;
def trap : SDNode<"ISD::TRAP" , SDTNone,
[SDNPHasChain, SDNPSideEffect]>;
-def debugger : SDNode<"ISD::DEBUGGER" , SDTNone,
+def debugtrap : SDNode<"ISD::DEBUGTRAP" , SDTNone,
[SDNPHasChain, SDNPSideEffect]>;
def prefetch : SDNode<"ISD::PREFETCH" , SDTPrefetch,
diff --git a/include/llvm/CodeGen/ISDOpcodes.h b/include/llvm/CodeGen/ISDOpcodes.h
index e570e12503af..7c2864fb4a98 100644
--- a/include/llvm/CodeGen/ISDOpcodes.h
+++ b/include/llvm/CodeGen/ISDOpcodes.h
@@ -582,8 +582,8 @@ namespace ISD {
// TRAP - Trapping instruction
TRAP,
- // DEBUGGER - Trap intented to get the attention of a debugger.
- DEBUGGER,
+ // DEBUGTRAP - Trap intented to get the attention of a debugger.
+ DEBUGTRAP,
// PREFETCH - This corresponds to a prefetch intrinsic. It takes chains are
// their first operand. The other operands are the address to prefetch,